import { SQS } from 'aws-sdk';
type ServiceLimit = {
    waitUntil: string;
    remaining: number;
    limit: number;
    used: number;
};
type ExecutionResult = {
    error?: string;
    status?: string;
    messages?: SQS.Message[];
};
/**
 * Lambda function executed by the release notes fetch step function to get the
 * list of packages for which the release notes have to be fetched. This
 * function considers the Github API service limitation and before returning
 * the list of packages
 * Pre conditions:
 * 1. Has valid Github credentials for making API requests
 * 2. Service quota limits have not be hit. If the limit has been hit, then
 * the function will return time when the quota will be reset so step function
 * can wait until then
 *
 * If these conditions are met, the function will return up to 10 packages
 * per execution
 *
 * @returns ExecutionResult | ServiceLimit
 */
export declare const handler: () => Promise<ExecutionResult | ServiceLimit>;
export {};
